@@ -1,18 +1,30 @@
 # pylint: disable=no-value-for-parameter
 """
-Main module for txt2ebook console app.
+Copyright (C) 2021,2022 Kian-Meng Ang
+
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU Affero General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU Affero General Public License for more details.
+
+You should have received a copy of the GNU Affero General Public License
+along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
-import sys
 from pathlib import Path
 from typing import Dict
 
 from bs4 import UnicodeDammit
-from configuror import Config
+from dotmap import DotMap
 from loguru import logger
 import click
 
-from txt2ebook import __version__
+from txt2ebook import __version__, setup_logger
 from txt2ebook.parsers import create_parser
 from txt2ebook.formatters import create_formatter
 
@@ -122,18 +134,11 @@ def main(**kwargs: Dict) -> None:
     """
     Console tool to convert txt file to different ebook format.
     """
-    config = Config(**kwargs)
-
-    logger.remove()
-    logger.add(
-        sys.stderr,
-        format="<green>{level: >5}</green>: {message}",
-        level=config["test_parsing"] and "DEBUG" or config["debug"] or "INFO",
-        colorize=True,
-    )
+    config = DotMap(**kwargs)
+    setup_logger(config)
 
     try:
-        filename = Path(config["input_file"])
+        filename = Path(config.input_file)
         logger.info("Parsing txt file: {}", filename.resolve())
 
         with open(filename, "rb") as file:
@@ -147,7 +152,7 @@ def main(**kwargs: Dict) -> None:
             parser = create_parser(content, config)
             book = parser.parse()
 
-            if config["test_parsing"] or config["debug"]:
+            if config.test_parsing or config.debug:
                 logger.debug(repr(book))
 
                 for volume in book.volumes:
@@ -158,15 +163,15 @@ def main(**kwargs: Dict) -> None:
                 for chapter in book.chapters:
                     logger.debug(repr(chapter))
 
-            if not config["test_parsing"]:
+            if not config.test_parsing:
                 if book.parsed_content:
                     writer = create_formatter(book, config)
                     writer.write()
 
                 # We write to txt for debugging purpose if output format is not
                 # txt.
-                if config["format"] != "txt":
-                    config["format"] = "txt"
+                if config.format != "txt":
+                    config.format = "txt"
                     txt_writer = create_formatter(book, config)
                     txt_writer.write()
 
